==> cordova-plugin-colleague-1.0.1.tgz: package/src/android/MupColleaguePlugin.java <==
package com.ygsoft.colleague;

import android.annotation.TargetApi;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.support.v4.util.SimpleArrayMap;
import android.widget.Toast;


import com.ygsoft.mup.expression.ExpressionManager;
import com.ygsoft.mup.expression.utils.ExpressionLoader;
import com.ygsoft.mup.utils.SharedPreferencesUtils;
import com.ygsoft.technologytemplate.core.global.TTCoreConfigInfo;
import com.ygsoft.technologytemplate.core.global.TTCoreInit;
import com.ygsoft.tt.colleague.ColleagueRecyclerViewFragment;
import com.ygsoft.tt.colleague.ColleagueShareRecycleViewActivity;
import com.ygsoft.tt.colleague.TTColleagueConfig;

import org.apache.cordova.CordovaInterface;
import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CallbackContext;

import org.apache.cordova.CordovaWebView;
import org.json.JSONArray;
import org.json.JSONException;
import org.litepal.LitePalApplication;

import java.util.ArrayList;
import java.util.List;

/**
 * This class echoes a string called from JavaScript.
 */
public class MupColleaguePlugin extends CordovaPlugin {

    private static final SimpleArrayMap<String, Integer> MIN_SDK_PERMISSIONS;

    private static final List<String> sPERMISSIONS;

    private String mAction = null;
    private JSONArray mArgs = null;
    private CallbackContext mCallbackContext = null;

    private int mRequestCode = 1234;

    static {
        MIN_SDK_PERMISSIONS = new SimpleArrayMap<String, Integer>(8);
        MIN_SDK_PERMISSIONS.put("com.android.voicemail.permission.ADD_VOICEMAIL", 14);
        MIN_SDK_PERMISSIONS.put("android.permission.BODY_SENSORS", 20);
        MIN_SDK_PERMISSIONS.put("android.permission.READ_CALL_LOG", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.READ_EXTERNAL_STORAGE", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.USE_SIP", 9);
        MIN_SDK_PERMISSIONS.put("android.permission.WRITE_CALL_LOG", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.SYSTEM_ALERT_WINDOW", 23);
        MIN_SDK_PERMISSIONS.put("android.permission.WRITE_SETTINGS", 23);
    }

    static {
        sPERMISSIONS = new ArrayList<String>();

        sPERMISSIONS.add("android.permission.CALL_PHONE");
        sPERMISSIONS.add("android.permission.READ_PHONE_STATE");
        sPERMISSIONS.add("android.permission.SEND_SMS");
        sPERMISSIONS.add("android.permission.RECORD_AUDIO");
        sPERMISSIONS.add("android.permission.WRITE_EXTERNAL_STORAGE");
        sPERMISSIONS.add("android.permission.GET_ACCOUNTS");
    }

    @Override
    public void initialize(CordovaInterface cordova, CordovaWebView webView) {

        //todo 还有一些初始化，比如联系人，会话调整

        //初始化数据库
        LitePalApplication.initialize(cordova.getActivity().getApplicationContext());

        TTColleagueConfig.getInstance().setColleagueLogic(new ColleagueECLogic());
        TTColleagueConfig.getInstance().setColleagueProxyBC(new ColleagueProxyBC());

        super.initialize(cordova, webView);
    }

    @Override
    public boolean execute(String action, JSONArray args, CallbackContext callbackContext) throws JSONException {
        if (!hasPermisssion()) {
            mAction = action;
            mArgs = args;
            mCallbackContext = callbackContext;
            requestPermissions(mRequestCode);
            return true;
        }

        if (action.equals("initBasePlugin")) {
            String initParams = args.getString(0);
            String userInfo = args.getString(1);
            TTCoreInit.init(cordova.getActivity().getApplication(), initParams, userInfo);
        } else if (action.equals("init")) {
            //初始化表情
            ExpressionManager.getInstance().setDownloadExpressionPath("restful/userimage/getImage/");
            ExpressionManager.getInstance().setDownloadExpressionServer(TTCoreConfigInfo.getInstance().getDefaultNetConfig().getServerUrl());
            try {
                ExpressionLoader.loaderAssetManagerPhizFaces(cordova.getActivity().getApplicationContext());
            } catch (Exception e) {
                e.printStackTrace();
            }
            return true;
        } else if (action.equals("open")) {
            Intent shareIntent = new Intent();
            shareIntent.setClass(cordova.getActivity(), ColleagueShareRecycleViewActivity.class);
            shareIntent.putExtra(ColleagueRecyclerViewFragment.INTENT_ISCOLLEAGUE_SHARE_KEY, true);
            cordova.getActivity().startActivity(shareIntent);
            return true;
        }
        return false;
    }

    @TargetApi(Build.VERSION_CODES.M)
    @Override
    public void requestPermissions(int requestCode) {
        mRequestCode = requestCode;
        String [] permissions = new String[sPERMISSIONS.size()];
        for (int i = 0; i < sPERMISSIONS.size(); i++) {
            permissions[i] = sPERMISSIONS.get(i);
        }
        cordova.getActivity().requestPermissions(permissions,  requestCode);
    }

    @Override
    public boolean hasPermisssion() {
        return hasSelfPermissions(sPERMISSIONS);

    }

    @Override
    public void onRequestPermissionResult(int requestCode, String[] permissions, int[] grantResults) throws JSONException {
        if (mRequestCode == requestCode) {
            if (verifyPermissions(grantResults)) {
                if (mAction != null && mArgs != null && mCallbackContext != null) {
                    execute(mAction, mArgs, mCallbackContext);
                    mAction = null;
                    mArgs = null;
                    mCallbackContext = null;
                }
            } else {
                Toast.makeText(cordova.getActivity(), "权限未获取,无法正常启动", Toast.LENGTH_LONG).show();
            }
        }
    }


    private boolean permissionExists(String permission) {
        // Check if the permission could potentially be missing on this device
        Integer minVersion = MIN_SDK_PERMISSIONS.get(permission);
        // If null was returned from the above call, there is no need for a device API level check for the permission;
        // otherwise, we check if its minimum API level requirement is met
        return minVersion == null || Build.VERSION.SDK_INT >= minVersion;
    }


    private boolean verifyPermissions(int... grantResults) {
        if (grantResults.length == 0) {
            return false;
        }
        for (int result : grantResults) {
            if (result != PackageManager.PERMISSION_GRANTED) {
                return false;
            }
        }
        return true;
    }


    private boolean hasSelfPermissions(List<String> permissions) {
        for (String permission : permissions) {
            if (permissionExists(permission) && !hasPermission(permission)) {
                return false;
            }
        }
        return true;
    }

    public boolean hasPermission(String permission) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            int result = cordova.getActivity().checkSelfPermission(permission);
            return PackageManager.PERMISSION_GRANTED == result;
        } else {
            return true;
        }
    }


    private void coolMethod(String message, CallbackContext callbackContext) {
        if (message != null && message.length() > 0) {
            callbackContext.success(message);
        } else {
            callbackContext.error("Expected one non-empty string argument.");
        }
    }
}

==> cordova-plugin-colleague-1.3.3.tgz: package/src/android/MupColleaguePlugin.java <==
package com.ygsoft.colleague;

import android.annotation.TargetApi;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.support.v4.util.SimpleArrayMap;
import android.widget.Toast;


import com.ygsoft.mup.expression.ExpressionManager;
import com.ygsoft.mup.expression.utils.ExpressionLoader;
import com.ygsoft.mup.utils.ResourceUtils;
import com.ygsoft.technologytemplate.core.global.TTCoreConfigInfo;
import com.ygsoft.technologytemplate.core.global.TTCoreInit;
import com.ygsoft.tt.colleague.ColleagueRecyclerViewFragment;
import com.ygsoft.tt.colleague.ColleagueShareRecycleViewActivity;
import com.ygsoft.tt.colleague.TTColleagueConfig;

import org.apache.cordova.CordovaInterface;
import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CallbackContext;

import org.apache.cordova.CordovaWebView;
import org.json.JSONArray;
import org.json.JSONException;
import org.litepal.LitePalApplication;

import java.util.ArrayList;
import java.util.List;

/**
 * This class echoes a string called from JavaScript.
 */
public class MupColleaguePlugin extends CordovaPlugin {

    private static final SimpleArrayMap<String, Integer> MIN_SDK_PERMISSIONS;

    private static final List<String> sPERMISSIONS;

    private String mAction = null;
    private JSONArray mArgs = null;
    private CallbackContext mCallbackContext = null;

    private int mRequestCode = 1236;

    static {
        MIN_SDK_PERMISSIONS = new SimpleArrayMap<String, Integer>(8);
        MIN_SDK_PERMISSIONS.put("com.android.voicemail.permission.ADD_VOICEMAIL", 14);
        MIN_SDK_PERMISSIONS.put("android.permission.BODY_SENSORS", 20);
        MIN_SDK_PERMISSIONS.put("android.permission.READ_CALL_LOG", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.READ_EXTERNAL_STORAGE", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.USE_SIP", 9);
        MIN_SDK_PERMISSIONS.put("android.permission.WRITE_CALL_LOG", 16);
        MIN_SDK_PERMISSIONS.put("android.permission.SYSTEM_ALERT_WINDOW", 23);
        MIN_SDK_PERMISSIONS.put("android.permission.WRITE_SETTINGS", 23);
    }

    static {
        sPERMISSIONS = new ArrayList<String>();

        sPERMISSIONS.add("android.permission.CALL_PHONE");
        sPERMISSIONS.add("android.permission.READ_PHONE_STATE");
        sPERMISSIONS.add("android.permission.SEND_SMS");
        sPERMISSIONS.add("android.permission.RECORD_AUDIO");
        sPERMISSIONS.add("android.permission.WRITE_EXTERNAL_STORAGE");
        sPERMISSIONS.add("android.permission.GET_ACCOUNTS");
    }

    @Override
    public void initialize(CordovaInterface cordova, CordovaWebView webView) {

        //todo 还有一些初始化，比如联系人，会话调整

        //初始化数据库
        LitePalApplication.initialize(cordova.getActivity().getApplicationContext());

        TTColleagueConfig.getInstance().setColleagueLogic(new ColleagueECLogic());
        TTColleagueConfig.getInstance().setColleagueProxyBC(new ColleagueProxyBC());

        super.initialize(cordova, webView);
    }

    @Override
    public boolean execute(String action, JSONArray args, CallbackContext callbackContext) throws JSONException {
        if (!hasPermisssion()) {
            mAction = action;
            mArgs = args;
            mCallbackContext = callbackContext;
            requestPermissions(mRequestCode);
            return true;
        }

        if (action.equals("initBasePlugin")) {
            String initParams = args.getString(0);
            String userInfo = args.getString(1);
            TTCoreInit.init(cordova.getActivity().getApplication(), initParams, userInfo);
        } else if (action.equals("init")) {

            int configId = ResourceUtils.getResourceId(cordova.getActivity().getApplicationContext(), "expression_config", ResourceUtils.RAW_TYPE);
            if (configId != 0) {
                ExpressionManager.initExpression(cordova.getActivity().getApplicationContext(), configId);
                ExpressionManager.getInstance().setDownloadExpressionServer(TTCoreConfigInfo.getInstance().getDefaultNetConfig().getServerUrl());
                try {
                    ExpressionLoader.loaderAssetManagerPhizFaces(cordova.getActivity().getApplicationContext());
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            return true;
        } else if (action.equals("open")) {
            Intent shareIntent = new Intent();
            shareIntent.setClass(cordova.getActivity(), ColleagueShareRecycleViewActivity.class);
            shareIntent.putExtra(ColleagueRecyclerViewFragment.INTENT_ISCOLLEAGUE_SHARE_KEY, true);
            cordova.getActivity().startActivity(shareIntent);
            return true;
        }
        return false;
    }

    @TargetApi(Build.VERSION_CODES.M)
    @Override
    public void requestPermissions(int requestCode) {
        mRequestCode = requestCode;
        String [] permissions = new String[sPERMISSIONS.size()];
        for (int i = 0; i < sPERMISSIONS.size(); i++) {
            permissions[i] = sPERMISSIONS.get(i);
        }
        cordova.requestPermissions(this, requestCode, permissions);
    }

    @Override
    public boolean hasPermisssion() {
        return hasSelfPermissions(sPERMISSIONS);

    }

    @Override
    public void onRequestPermissionResult(int requestCode, String[] permissions, int[] grantResults) throws JSONException {
        if (mRequestCode == requestCode) {
            if (verifyPermissions(grantResults)) {
                if (mAction != null && mArgs != null && mCallbackContext != null) {
                    execute(mAction, mArgs, mCallbackContext);
                    mAction = null;
                    mArgs = null;
                    mCallbackContext = null;
                }
            } else {
                Toast.makeText(cordova.getActivity(), "权限未获取,无法正常启动", Toast.LENGTH_LONG).show();
            }
        }
    }


    private boolean permissionExists(String permission) {
        // Check if the permission could potentially be missing on this device
        Integer minVersion = MIN_SDK_PERMISSIONS.get(permission);
        // If null was returned from the above call, there is no need for a device API level check for the permission;
        // otherwise, we check if its minimum API level requirement is met
        return minVersion == null || Build.VERSION.SDK_INT >= minVersion;
    }


    private boolean verifyPermissions(int... grantResults) {
        if (grantResults.length == 0) {
            return false;
        }
        for (int result : grantResults) {
            if (result != PackageManager.PERMISSION_GRANTED) {
                return false;
            }
        }
        return true;
    }


    private boolean hasSelfPermissions(List<String> permissions) {
        for (String permission : permissions) {
            if (permissionExists(permission) && !hasPermission(permission)) {
                return false;
            }
        }
        return true;
    }

    public boolean hasPermission(String permission) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            int result = cordova.getActivity().checkSelfPermission(permission);
            return PackageManager.PERMISSION_GRANTED == result;
        } else {
            return true;
        }
    }


    private void coolMethod(String message, CallbackContext callbackContext) {
        if (message != null && message.length() > 0) {
            callbackContext.success(message);
        } else {
            callbackContext.error("Expected one non-empty string argument.");
        }
    }
}
